=========
endorphin
=========


.. image:: https://img.shields.io/pypi/v/endorphin.svg
        :target: https://pypi.python.org/pypi/endorphin

.. image:: https://img.shields.io/travis/xq5he/endorphin.svg
        :target: https://travis-ci.org/xq5he/endorphin

.. image:: https://readthedocs.org/projects/endorphin/badge/?version=latest
        :target: https://endorphin.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A C++ Project boilerplate


* Free software: MIT license
* Documentation: https://endorphin.readthedocs.io.


Features
--------

* TODO

References
-----------

1. https://cliutils.gitlab.io/modern-cmake/
